"""added taker_buy_sell

Revision ID: 724b55f51ade
Revises: c5800ee0c7ab
Create Date: 2024-09-14 18:42:44.246135

"""

import sqlalchemy as sa
from alembic import op
from sqlalchemy.dialects import postgresql

# revision identifiers, used by Alembic.
revision = "724b55f51ade"
down_revision = "c5800ee0c7ab"
branch_labels = None
depends_on = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    exchange_enum = postgresql.ENUM(name="exchange", schema="public", create_type=False)

    op.create_table(
        "taker_buy_sell",
        sa.Column("buy_vol", sa.Float(), nullable=False),
        sa.Column("sell_vol", sa.Float(), nullable=False),
        sa.Column("exchange", exchange_enum),
        sa.Column("symbol", sa.String(), nullable=False),
        sa.Column("timestamp", sa.BIGINT(), nullable=False),
        sa.Column("datetime", sa.DateTime(), nullable=False),
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("created_at", sa.TIMESTAMP(), nullable=False),
        sa.Column("updated_at", sa.TIMESTAMP(), nullable=False),
        sa.PrimaryKeyConstraint("id"),
        schema="crypto",
    )
    op.create_index(
        "ix_taker_buy_sell_created_at",
        "taker_buy_sell",
        ["created_at"],
        unique=False,
        schema="crypto",
    )
    op.create_index(
        "ix_taker_buy_sell_exchange_symbol_timestamp",
        "taker_buy_sell",
        ["exchange", "symbol", "timestamp"],
        unique=True,
        schema="crypto",
    )
    op.create_index(
        "ix_taker_buy_sell_time_of_minute",
        "taker_buy_sell",
        [sa.text("EXTRACT(minute from datetime)")],
        unique=False,
        schema="crypto",
    )
    op.create_index(
        "ix_taker_buy_sell_timestamp",
        "taker_buy_sell",
        ["timestamp"],
        unique=False,
        schema="crypto",
    )
    op.create_index(
        "ix_taker_buy_sell_updated_at",
        "taker_buy_sell",
        ["updated_at"],
        unique=False,
        schema="crypto",
    )

    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_index(
        "ix_taker_buy_sell_updated_at",
        table_name="taker_buy_sell",
        schema="crypto",
    )
    op.drop_index(
        "ix_taker_buy_sell_timestamp",
        table_name="taker_buy_sell",
        schema="crypto",
    )
    op.drop_index(
        "ix_taker_buy_sell_time_of_minute",
        table_name="taker_buy_sell",
        schema="crypto",
    )
    op.drop_index(
        "ix_taker_buy_sell_exchange_symbol_timestamp",
        table_name="taker_buy_sell",
        schema="crypto",
    )
    op.drop_index(
        "ix_taker_buy_sell_created_at",
        table_name="taker_buy_sell",
        schema="crypto",
    )
    op.drop_table("taker_buy_sell", schema="crypto")
    # ### end Alembic commands ###
